@@ -1,4 +1,3 @@
-# flake8: noqa
 # -*- coding: utf-8 -*-
 from south.utils import datetime_utils as datetime
 from south.db import db
@@ -218,7 +217,7 @@ class Migration(SchemaMigration):
             ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
             ('operation', self.gf('django.db.models.fields.related.ForeignKey')(related_name='suboperations', to=orm['aps_process.Operation'])),
             ('priority', self.gf('django.db.models.fields.IntegerField')(default=1)),
-            ('suboperation', self.gf('django.db.models.fields.related.ForeignKey')(related_name='superoperations', to=orm['aps_process.Operation'])),
+            ('suboperation', self.gf('django.db.models.fields.related.ForeignKey')(blank=True, related_name='superoperations', null=True, to=orm['aps_process.SubOperation'])),
             ('effective_start', self.gf('django.db.models.fields.DateTimeField')(null=True, blank=True)),
             ('effective_end', self.gf('django.db.models.fields.DateTimeField')(null=True, blank=True)),
         ))
@@ -453,8 +452,8 @@ class Migration(SchemaMigration):
             'operation': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'suboperations'", 'to': u"orm['aps_process.Operation']"}),
             'priority': ('django.db.models.fields.IntegerField', [], {'default': '1'}),
             'source': ('django.db.models.fields.CharField', [], {'max_length': '20', 'blank': 'True'}),
-            'suboperation': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'superoperations'", 'to': u"orm['aps_process.Operation']"})
+            'suboperation': ('django.db.models.fields.related.ForeignKey', [], {'blank': 'True', 'related_name': "'superoperations'", 'null': 'True', 'to': u"orm['aps_process.SubOperation']"})
         }
     }
 
-    complete_apps = ['aps_process']
+    complete_apps = ['aps_process']
\ No newline at end of file
