@@ -584,8 +584,10 @@ class SubOperation(DateAndSource):
     operation = models.ForeignKey(Operation, verbose_name=_('Operation'),
                                   related_name='suboperations')
     priority = models.IntegerField(verbose_name=_('Priority'), default=1)
-    suboperation = models.ForeignKey(Operation, verbose_name=_('Suboperation'),
-                                     related_name='superoperations')
+    suboperation = models.ForeignKey('aps_process.SubOperation',
+                                     verbose_name=_('Suboperation'),
+                                     related_name='superoperations',
+                                     blank=True, null=True)
     effective_start = models.DateTimeField(verbose_name=_('Effective start'),
                                            blank=True, null=True)
     effective_end = models.DateTimeField(verbose_name=_('Effective end'),
